#read in output of model2
d <- read.csv("Dall.csv", header=T)

#plot of B1 posterior credible intervals by predictor
library(tidyverse)
d %>%
  mutate(predictor = fct_relevel(predictor, c("endocranial","residualbrain","logcortneurons","logcerebneurons","logcortneurdens","logcerebneurdens","frugivory","logpopsize","loghomerange","logdayjourney","selfcontrol2","gencogrev")),
         predictor = factor(predictor, labels = c("Endocranial volume", "Residual brain volume", "Cortical neuron number", "Cerebellum neuron number","Cortical neuron density","Cerebellum neuron density", "Frugivory","Group size","Home range size","Day journey length","Self-control", "General cognitive score")),
         predictor = fct_rev(predictor)) %>%
  ggplot(aes(x=predictor, y=b1.50, color=category)) +
  scale_color_manual(values=c("black","purple","olivedrab")) +
  geom_hline(yintercept=0, color="darkblue") +
  geom_errorbar(aes(ymin=b1.25, ymax=b1.75), size=0.8,width=0.2) +
  geom_errorbar(aes(ymin=b1.5,  ymax=b1.95), size=0.8, width=0.0, alpha=0.4) +   
  geom_point(size=3) +
  coord_flip() +
  theme_classic() +
  theme(legend.position = "top",
        legend.text = element_text(size=12),
        legend.title = element_text(size=12),
        axis.text=element_text(size=12),
        axis.title.x=element_text(size=12),
        axis.title.y=element_text(size=12)) +
  xlab("Predictor") + ylab("Coefficient") + ylim(-0.5, 0.5)
