library(ggplot2)
library(viridis)
library(cowplot)

d <- read.csv("SpeciesPredictors.csv", header=T)

#combined scatterplots for strong and marginal effects for predictors by animal group

#scatterplot log cortical neuron density by species w
p1 <- ggplot(d, aes(x=logcortneurdens, y=w, shape=group, color=group)) +
  scale_shape_manual(values = c(5, 16, 17))+
  scale_color_manual(values = c("red3","royalblue4","darkgreen"))+
  geom_point(size=3) +
  geom_smooth(method=lm,se=FALSE,linetype="dashed", size = 0.5)+
  theme_classic()+
  theme(axis.text.x=element_text(size=10),
        axis.text.y=element_text(size=10),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10),
        axis.title.x=element_text(size=10),
        axis.title.y=element_text(size=10)) +
  theme(legend.position = "none") +
  xlab("log(Cortical neuron density)") + ylab("w")+ ylim(0,1.8)

p2 <- ggplot(d, aes(x=logcerebneurdens, y=w, shape=group, color=group)) +
  scale_shape_manual(values = c(5, 16, 17))+
  scale_color_manual(values = c("red3","royalblue4","darkgreen"))+
  geom_point(size=3) +
  geom_smooth(method=lm,se=FALSE,linetype="dashed", size = 0.5)+
  theme_classic()+
  theme(axis.text.x=element_text(size=10),
        axis.text.y=element_text(size=10),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10),
        axis.title.x=element_text(size=10),
        axis.title.y=element_text(size=10)) +
  theme(legend.position = "none") +
  xlab("log(Cerebellum neuron density)") + ylab("w") + ylim(0,1.8)

#scatterplot general cognitive score (reversed for clarity) and species w
p3 <- ggplot(d, aes(x=gencogrev, y=w, shape=group, color=group)) +
  scale_shape_manual(values = c(5, 16, 17))+
  scale_color_manual(values = c("red3","royalblue4","darkgreen"))+
  geom_point(size=3) +
  geom_smooth(method=lm,se=FALSE,linetype="dashed", size = 0.5)+
  theme_classic() +
  theme(axis.text.x=element_text(size=10),
        axis.text.y=element_text(size=10),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10),
        axis.title.x=element_text(size=10),
        axis.title.y=element_text(size=10)) +
  theme(legend.position = "none") +
  xlab("General cognitive score") + ylab("w")+ ylim(0,1.8)

#scatterplot residual brain volume by species w
p4 <- ggplot(d, aes(x=residualbrain, y=w, shape=group, color=group)) +
  scale_shape_manual(values = c(5, 16, 17))+
  scale_color_manual(values = c("red3","royalblue4","darkgreen"))+
  geom_point(size=3) +
  geom_smooth(method = "lm", se=FALSE, linetype="dashed", size = 0.5)+
  theme_classic()+
  theme(axis.text.x=element_text(size=10),
        axis.text.y=element_text(size=10),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10),
        axis.title.x=element_text(size=10),
        axis.title.y=element_text(size=10)) +
  theme(legend.position = "none") +
  xlab("Residual brain volume") + ylab("w") + ylim(0,1.8)

#scatterplot frugivory by species w, note we only have predictor data for primates
# p5 <- ggplot(d, aes(x=frugivory, y=w, shape=group, color=group)) +
#   scale_shape_manual(values = c(5, 16, 17))+
#   scale_color_manual(values = c("red3","royalblue4","darkgreen"))+
#   geom_point(size=3) +
#   geom_smooth(method=lm,se=FALSE,linetype="dashed", size = 0.5)+
#   theme_classic()+
#   theme(axis.text.x=element_text(size=10),
#         axis.text.y=element_text(size=10),
#         legend.text = element_text(size=10),
#         legend.title = element_text(size=10),
#         axis.title.x=element_text(size=10),
#         axis.title.y=element_text(size=10)) +
#   theme(legend.position = "none") +
#   xlab("Percentage fruit in diet") + ylab("w") + ylim(0,1.8)

#scatterplot group size (pop group size) by species w, have data for 28 species
p6 <- ggplot(d, aes(x=logpopsize, y=w, shape=group, color=group)) +
  scale_shape_manual(values = c(5, 16, 17))+
  scale_color_manual(values = c("red3","royalblue4","darkgreen"))+
  geom_point(size=3) +
  geom_smooth(method=lm,se=FALSE,linetype="dashed", size = 0.5)+
  theme_classic()+
  theme(axis.text.x=element_text(size=10),
        axis.text.y=element_text(size=10),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10),
        axis.title.x=element_text(size=10),
        axis.title.y=element_text(size=10)) +
  theme(legend.position = "none") +
  xlab("log(Group size)") + ylab("w") + ylim(0,1.8)


# multsp1 <- plot_grid(
#   p1 + theme(legend.position="none"),
#   p2 + theme(legend.position="none"),
#   p3 + theme(legend.position="none"),
#   labels = c("A", "B", "C"),
#   nrow = 2
# )
# 
# multsp2 <- plot_grid(
#   p4 + theme(legend.position="none"),
#   p5 + theme(legend.position="none"),
#   p6 + theme(legend.position="none"),
#   labels = c("D","E","F"),
#   nrow = 2
# )
# 
# legend <- get_legend(
#   # create some space to the left of the legend
#   p3 + theme(legend.box.margin = margin(0, 0, 0, 12))
# )
# 
# # add the legend to the row we made earlier. Give it one-third of 
# # the width of one plot (via rel_widths).
# plot_grid(multsp, legend, rel_widths = c(3, .4))
